@@ -1,10 +1,12 @@
-use std::borrow::Cow;
+use alloc::borrow::Cow;
+use alloc::string::String;
+use crate::alloc::borrow::ToOwned;
 
 #[derive(Debug)]
 pub enum Error {
     Generic(Cow<'static, str>),
-    Http(u32, String),
-    Rest(u32, String),
+    Http(u16, String),
+    Rest(u16, String),
     JsError(js_sys::Error),
 }
 
@@ -18,10 +20,8 @@ impl Error {
     }
 }
 
-impl std::error::Error for Error {}
-
-impl std::fmt::Display for Error {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+impl core::fmt::Display for Error {
+    fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
         match self {
             Error::Generic(message) => f.write_str(&message),
             Error::Http(status, message) => write!(f, "HTTP Error {}, {}", status, message),
